`xotl.tools.fs.path`:mod: -- Path utilities
===========================================

.. automodule:: xotl.tools.fs.path
   :members: join, fix_encoding, normalize_path, shorten_module_filename,
             shorten_user, rtrim
